@@ -1,6 +1,8 @@
 import pandas as pd
 import random
 import smtplib
+from email.mime.multipart import MIMEMultipart
+from email.mime.text import MIMEText
 from getpass import getpass
 from IPython.core.magic import  Magics, magics_class, cell_magic, line_magic
 
@@ -47,42 +49,64 @@ class list_upload:
         ganador = random.choice(col)
         return ganador
 
-    def send_mail(self,asunto,mensaje,test_mail=False):
+    def send_mail(self,asunto,mensaje,correo,test_mail=False):
+
         df = self.show
-        gmail_user = 'jhonny.osorio@profesores.uamerica.edu.co'
-        gmail_password = getpass("Enter password ")
+        sender_address = correo
+        sender_pass = getpass("Enter password ")
 
         subject = asunto
-        message = mensaje 
+        messenger = mensaje 
 
         if test_mail== True:
             nombre = df["nombres"][0].split()[0]
-            mail_from = gmail_user
-            mail_to   = gmail_user
-            mail_subject = subject
-            mail_message_body = message.format(nombre)
-            mail_message ='Subject: {}\n\n{}'.format(mail_subject, mail_message_body)
+
+            receiver_address = correo
+
+            message = MIMEMultipart()
+            message['From'] = sender_address
+            message['To'] = receiver_address
+            message['Subject'] = subject 
+
+            mail_content = messenger.format(nombre) 
+
+
             # Sent Email
             # https://www.google.com/settings/security/lesssecureapps
-            server = smtplib.SMTP_SSL('smtp.gmail.com', 465)
-            server.login(gmail_user, gmail_password)
-            server.sendmail(mail_from, mail_to, mail_message)
-            server.close()
+            # https://support.google.com/accounts/answer/185839 verificación en dos pasos
+
+            message.attach(MIMEText(mail_content, 'plain'))
+            session = smtplib.SMTP('smtp.gmail.com', 587)
+            session.starttls()
+            session.login(sender_address, sender_pass)
+            text = message.as_string()
+            session.sendmail(sender_address, receiver_address, text)
+            session.quit()
             print("Mail Sent Successfully")
 
         else:
             
             for i in range(df.shape[0]):
                 nombre = df["nombres"][i].split()[0]
-                mail_from = gmail_user
-                mail_to   = df["correos"][i].split()[0]
-                mail_subject = subject
-                mail_message_body = message.format(nombre)
-                mail_message ='Subject: {}\n\n{}'.format(mail_subject, mail_message_body)
+
+                receiver_address = df["correos"][i].split()[0]
+
+                message = MIMEMultipart()
+                message['From'] = sender_address
+                message['To'] = receiver_address
+                message['Subject'] = subject 
+
+                mail_content = messenger.format(nombre)
+
                 # Sent Email
-                # https://www.google.com/settings/security/lesssecureapps
-                server = smtplib.SMTP_SSL('smtp.gmail.com', 465)
-                server.login(gmail_user, gmail_password)
-                server.sendmail(mail_from, mail_to, mail_message)
-                server.close()
+                message.attach(MIMEText(mail_content, 'plain'))
+                session = smtplib.SMTP('smtp.gmail.com', 587)
+                session.starttls()
+                session.login(sender_address, sender_pass)
+                text = message.as_string()
+                session.sendmail(sender_address, receiver_address, text)
+
+            session.quit()
             print("Successfully Sent Emails")
+
+            
